==> claws-mail_3.7.5.orig.tar.gz: claws-mail-3.7.5/src/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Hoà Viêt Dinh <hoa@users.sf.net>",
"Andrej Kacian <andrej@kacian.sk>",
"Darko Koruga <darko@users.sf.net>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Paweł Pękala <c0rn@o2.pl>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Werner Koch",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[bg] Yasen Pramatarov <yasen@lindeas.com>",
"[ca] Miquel Oliete <ktalanet@yahoo.es>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[de] Stephan Sachse <white@dev-zero.com>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Colin Leroy <colin@colino.net>",
"[hu] Pader Rezso <rezso@rezso.net>",
"[id] MSulchan Darmawan <bleketux@gmail.com>",
"[it] Andrea Spadaccini <a.spadaccini@catania.linux.it>",
"[ja] kazken3 <kazken3@gmail.com>",
"[nl] Marcel Pol <mpol@gmx.net>",
"[pl] Emilian Nowak <emil5@go2.pl>",
"[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
"[pt_PT] Tiago Faria <gouki@goukihq.org>",
"[ru] Aleksei Miheev <aleksei@miheev.info>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Lars Persson Fink <lars.p.fink@gmail.com>",
"[zh_CN] Ralgh Young <bamanzi@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Paweł Pękala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urosevic <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"Sergei Astanin",
"Ruslan N. Balkin",
"Fabio Junior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Didier Barvaux",
"Jean-Luc Biord",
"Pavlo Bohmat",
"Eugene Brevdo",
"André Filipe de Assunção e Brito",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Jonathan Corbet",
"Christian Cornelssen",
"George Danchev",
"Matthieu Dazy",
"Pierric Descamps",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Bob Forsman",
"Matthias Förste",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Thierry Godefroy",
"Alex Gorbachenko",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"WAKAI Kazunao",
"Fabian Keil",
"Martin Kluge",
"IWAMOTO Kouichi",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Tim Mann",
"Ivan Francolin Martinez",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Ales Nosek",
"James Noyes",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Fredrik Olofssen",
"Reza Pakdel",
"Martin Pool",
"Quar",
"Don Quijote",
"Jens Rantil",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Chad Robinson",
"Paul Rolland",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Rodrigo Dias Arruda Senra",
"Setoh",
"shigeri",
"Gustavo Noronha Silva",
"Jesse Skinner",
"Ville Skyttä",
"Dale P. Smith",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Anders Troback",
"Tsutsui",
"Aleksandar Urosevic",
"Petr Vanek",
"Jeroen Versteeg",
"Kevin Vigor",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};

==> claws-mail_3.7.6.orig.tar.gz: claws-mail-3.7.6/src/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Hoà Viêt Dinh <hoa@users.sf.net>",
"Andrej Kacian <andrej@kacian.sk>",
"Darko Koruga <darko@users.sf.net>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Paweł Pękala <c0rn@o2.pl>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Werner Koch",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[bg] Yasen Pramatarov <yasen@lindeas.com>",
"[ca] Miquel Oliete <ktalanet@yahoo.es>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[de] Stephan Sachse <white@dev-zero.com>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Colin Leroy <colin@colino.net>",
"[hu] Páder Rezső <rezso@rezso.net>",
"[id] MSulchan Darmawan <bleketux@gmail.com>",
"[it] Andrea Spadaccini <a.spadaccini@catania.linux.it>",
"[ja] kazken3 <kazken3@gmail.com>",
"[nl] Marcel Pol <mpol@gmx.net>",
"[pl] Emilian Nowak <emil5@go2.pl>",
"[pt_BR] Frederico Goncalves Guimaraes <fggdebian@yahoo.com.br>",
"[pt_PT] Tiago Faria <gouki@goukihq.org>",
"[ru] Aleksei Miheev <aleksei@miheev.info>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Lars Persson Fink <lars.p.fink@gmail.com>",
"[uk] YUP <yupadmin@gmail.com>",
"[zh_CN] Ralgh Young <bamanzi@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[de] Volker Ribbert <thoraki@arcor.de>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Paweł Pękala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urosevic <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"Sergei Astanin",
"Ruslan N. Balkin",
"Fabio Junior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Didier Barvaux",
"Laurent Bigonville",
"Jean-Luc Biord",
"Pavlo Bohmat",
"Eugene Brevdo",
"André Filipe de Assunção e Brito",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Jonathan Corbet",
"Christian Cornelssen",
"George Danchev",
"Matthieu Dazy",
"Pierric Descamps",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Bob Forsman",
"Matthias Förste",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Thierry Godefroy",
"Alex Gorbachenko",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"WAKAI Kazunao",
"Fabian Keil",
"Martin Kluge",
"IWAMOTO Kouichi",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Tim Mann",
"Ivan Francolin Martinez",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Ales Nosek",
"James Noyes",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Fredrik Olofssen",
"Reza Pakdel",
"Martin Pool",
"Quar",
"Don Quijote",
"Jens Rantil",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Chad Robinson",
"Paul Rolland",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Rodrigo Dias Arruda Senra",
"Setoh",
"shigeri",
"Gustavo Noronha Silva",
"Jesse Skinner",
"Ville Skyttä",
"Dale P. Smith",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Anders Troback",
"Tsutsui",
"Aleksandar Urosevic",
"Petr Vanek",
"Jeroen Versteeg",
"Kevin Vigor",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};
